**Devlog guidelines:**
- All new code needs to be tested and documented. Add daily tasks accordingly.
- The written dissertation (or at least the notes to write it) needs to move along with all the other goals.

# Daily sprint goals

- ~~finish all tests on existing classes~~
- ~~build docs on existing classes~~
- ~~implement prediction on existing classes~~

# Tasks for the day

- [x] test SVM
- [x] implement prediction
	- [x] LDA
	- [x] SVM
- [x] make docs
	- [x] LLDF
	- [x] PCA
	- [x] LDA
	- [x] SVM

# Notes

- 

# Shutdown and Retrospective

- [x] test and validate all new code
- [x] commit to the remote repo
- [ ] make a schedule for tomorrow

**Did anything go wrong? What could have been done better, and how?**
- Finally, the process is up and running and everything can be done up to plan.